@@ -5,18 +5,28 @@
 #----------------------
 
 # test to make sure that the I/O structures across regression functions are correct.
-fin <- system.file('extdata',
-                   'NEON.D15.ONAQ.DP4.00200.001.nsae.2019-05.basic.packed.h5',
-                   package = 'NEONiso', mustWork = TRUE)
-co2test <- ingest_data(fin, analyte = 'Co2')
+fin <- system.file("extdata",
+                   "NEON.D15.ONAQ.DP4.00200.001.nsae.2019-05.basic.packed.h5",
+                   package = "NEONiso", mustWork = TRUE)
+co2test <- ingest_data(fin, analyte = "Co2", avg = 9)
 co2data <- NEONiso:::extract_carbon_calibration_data(co2test$refe_stacked)
-calDf_B03 <- NEONiso:::fit_carbon_regression(co2data, method = "Bowling_2003", calibration_half_width = 2)
-calDf_LR <- NEONiso:::fit_carbon_regression(co2data, method = "linreg", calibration_half_width = 2)
+calDf_B03 <- NEONiso:::fit_carbon_regression(co2data,
+                                             method = "Bowling_2003",
+                                             calibration_half_width = 2)
+calDf_LR <- NEONiso:::fit_carbon_regression(co2data,
+                                            method = "linreg",
+                                            calibration_half_width = 2)
 
 test_that("fit_carbon_regression returns data.frame", {
   skip_on_cran()
-  expect_s3_class(fit_carbon_regression(co2data, method = "Bowling_2003", calibration_half_width = 2), "data.frame")
-  expect_s3_class(fit_carbon_regression(co2data, method = "linreg", calibration_half_width = 2), "data.frame")
+  expect_s3_class(fit_carbon_regression(co2data,
+                                        method = "Bowling_2003",
+                                        calibration_half_width = 2),
+                  "data.frame")
+  expect_s3_class(fit_carbon_regression(co2data,
+                                        method = "linreg",
+                                        calibration_half_width = 2),
+                  "data.frame")
 })
 
 test_that("calibration data frames have 14 columns", {
@@ -31,10 +41,10 @@ test_that("calibration data frames have 14 columns", {
 # test carbon - bowling ambient calibration
 temp <- calibrate_ambient_carbon_Bowling2003(co2test$ambient$`000_010_09m`,
                                              calDf_B03,
-                                             site = 'ONAQ')
+                                             site = "ONAQ")
 temp_gf <- calibrate_ambient_carbon_Bowling2003(co2test$ambient$`000_010_09m`,
                                            calDf_B03,
-                                           site = 'ONAQ',
+                                           site = "ONAQ",
                                            gap_fill_parameters = TRUE)
 
 test_that("calibrate_ambient_carbon_Bowling2003 returns a list",{
@@ -46,8 +56,9 @@ test_that("calibrate_ambient_carbon_Bowling2003 returns a list",{
 test_that("calibrate_ambient_carbon_Bowling2003 returns correct variables", {
   skip_on_cran()
   vars <- c("dlta13CCo2", "pres", "presEnvHut", "rhEnvHut",
-            "rtioMoleDry12CCo2", "rtioMoleDry13CCo2", "rtioMoleDryCo2", "rtioMoleDryH2o",
-            "rtioMoleWet12CCo2", "rtioMoleWet13CCo2", "rtioMoleWetCo2", "rtioMoleWetH2o",
+            "rtioMoleDry12CCo2", "rtioMoleDry13CCo2", "rtioMoleDryCo2", 
+            "rtioMoleDryH2o", "rtioMoleWet12CCo2", "rtioMoleWet13CCo2",
+            "rtioMoleWetCo2", "rtioMoleWetH2o",
             "rtioMoleWetH2oEnvHut", "temp", "tempEnvHut")
   expect_equal(names(temp), vars)
   expect_equal(names(temp_gf), vars)
@@ -77,8 +88,9 @@ test_that("calibrate_ambient_carbon_linreg returns a list",{
 test_that("calibrate_ambient_carbon_linreg returns correct variables", {
   skip_on_cran()
   vars <- c("dlta13CCo2", "pres", "presEnvHut", "rhEnvHut",
-            "rtioMoleDry12CCo2", "rtioMoleDry13CCo2", "rtioMoleDryCo2", "rtioMoleDryH2o",
-            "rtioMoleWet12CCo2", "rtioMoleWet13CCo2", "rtioMoleWetCo2", "rtioMoleWetH2o",
+            "rtioMoleDry12CCo2", "rtioMoleDry13CCo2", "rtioMoleDryCo2",
+            "rtioMoleDryH2o", "rtioMoleWet12CCo2", "rtioMoleWet13CCo2",
+            "rtioMoleWetCo2", "rtioMoleWetH2o",
             "rtioMoleWetH2oEnvHut", "temp", "tempEnvHut")
   expect_equal(names(temp), vars)
   expect_equal(names(temp_gf), vars)
@@ -99,14 +111,23 @@ test_that("calibrated d13C values have been added to calibrate_ambient_cabron_li
 wiso_ref <- neonUtilities::stackEddy(fin, level = "dp01", avg = 3)
 
 # extract standards data.
-high <- subset(wiso_ref[["ONAQ"]], wiso_ref[["ONAQ"]]$verticalPosition == 'h2oHigh')
-med  <- subset(wiso_ref[["ONAQ"]], wiso_ref[["ONAQ"]]$verticalPosition == 'h2oMed')
-low  <- subset(wiso_ref[["ONAQ"]], wiso_ref[["ONAQ"]]$verticalPosition == 'h2oLow')
+high <- subset(wiso_ref[["ONAQ"]], 
+               wiso_ref[["ONAQ"]]$verticalPosition == "h2oHigh")
+med  <- subset(wiso_ref[["ONAQ"]], 
+               wiso_ref[["ONAQ"]]$verticalPosition == "h2oMed")
+low  <- subset(wiso_ref[["ONAQ"]], 
+               wiso_ref[["ONAQ"]]$verticalPosition == "h2oLow")
 
 # restructure standards data.  
-high_rs <- extract_water_calibration_data(high, standard = 'high', method = 'by_site')
-med_rs  <- extract_water_calibration_data(med, standard = 'med', method = 'by_site')
-low_rs  <- extract_water_calibration_data(low, standard = 'low', method = 'by_site')
+high_rs <- extract_water_calibration_data(high,
+                                          standard = "high",
+                                          method = "by_site")
+med_rs  <- extract_water_calibration_data(med,
+                                          standard = "med",
+                                          method = "by_site")
+low_rs  <- extract_water_calibration_data(low,
+                                          standard = "low",
+                                          method = "by_site")
 
 # add fix for NEON standard swap.
 low_rs <- swap_standard_isotoperatios(low_rs)
@@ -180,11 +201,11 @@ out <- fit_water_regression(stds,
                             calibration_half_width = 14,
                             slope_tolerance = 9999,
                             r2_thres = 0.9)
-data_by_height_by_var <- restructure_ambient_data(fin, 'H2o')
+data_by_height_by_var <- restructure_ambient_data(fin, "H2o")
 
 # test restructure_ambient_data:
-test_that("restructure_ambient_data returns a list with 2 elements for modified ONAQ file", {
-  expect_equal(length(restructure_ambient_data(fin, 'H2o')), 2)
+test_that("restructure_ambient_data returns a list with 1 elements for modified ONAQ file", {
+  expect_equal(length(restructure_ambient_data(fin, "H2o")), 1)
   expect_type(data_by_height_by_var, "list")
 })
 
